Calculate the prediction values and prediction errors across all candidate models.
plam.fit(
M,
nump,
numq,
a3,
X.train,
ZZ.train,
y.train,
X.pred,
ZZ.pred,
y.pred,
nbasis,
tt
)A list of
A matrix of prediction values on training data set for M candidate models.
A matrix of prediction errors on training data set for M candidate models.
A matrix of prediction values on test data set for M candidate models.
A matrix of prediction errors on test data set for M candidate models.
A vector of effective degree of freedom for M candidate models.
The number of candidate models.
The number of scalar predictors in candidate models.
The number of funtional principal components (FPCs) in candidate models.
The index for each component in each candidate model. See modelspec.
The training data of scalar predictors.
The training data of the functional predictor.
The training data of response variable.
The test data of scalar predictors.
The test data of the functional predictor.
The test data of response variable.
The number of basis functions used for spline approximation.
The vector of recording/measurement points for the functional predictor.